#[non_exhaustive]pub struct RoomPolicyEventContent {
pub via: OwnedServerName,
pub public_keys: BTreeMap<SigningKeyAlgorithm, Base64>,
}Available on crate feature
events only.Expand description
The content of an m.room.policy event.
A Policy Server configuration.
If invalid or not set, the room does not use a Policy Server.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.via: OwnedServerNameThe server name to use as a Policy Server.
MUST have a joined user in the room.
public_keys: BTreeMap<SigningKeyAlgorithm, Base64>The public keys for the Policy Server.
MUST contain at least ed25519.
Implementations
Sourceimpl RoomPolicyEventContent
impl RoomPolicyEventContent
Sourcepub fn new(
via: OwnedServerName,
ed25519_public_key: Base64,
) -> RoomPolicyEventContent
pub fn new( via: OwnedServerName, ed25519_public_key: Base64, ) -> RoomPolicyEventContent
Creates a new RoomPolicyEventContent with the given server name and ed25519 public key.